
delphin.commands
================

.. automodule:: delphin.commands

   The public functions in this module largely mirror the front-end
   subcommands provided by the `delphin` command, with some small
   changes to argument names or values to be better-suited to being
   called from within Python.

   convert
   -------

   .. autofunction:: convert

   select
   ------

   .. autofunction:: select

   mkprof
   ------

   .. autofunction:: mkprof

   process
   -------

   .. autofunction:: process

   compare
   -------

   .. autofunction:: compare

   repp
   ----

   .. autofunction:: repp

   Exceptions
   ----------

   .. autoexception:: CommandError
